.. _swh-objstorage:

Software Heritage - Object storage
==================================

Content-addressable object storage.


Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2

   cli
   winery

.. only:: standalone_package_doc

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
